@@ -10,7 +10,7 @@ module RD
     include Enumerable
 
     SYSTEM_NAME = "RDtool Framework -- Document Tree"
-    SYSTEM_VERSION = "$Version: 0.6.20$" #"
+    SYSTEM_VERSION = "$Version: 0.6.21$" #"
     VERSION = Version.new_from_version_string(SYSTEM_NAME, SYSTEM_VERSION)
 
     def Tree.version
@@ -47,7 +47,8 @@ module RD
     
     def parse
       parser = RDParser.new
-      set_root(parser.parse(@src.to_a, self))
+      src = @src.respond_to?(:to_a) ? @src.to_a : @src.split(/^/)
+      set_root(parser.parse(src, self))
     end
 
     def set_root(element)
