@@ -1,6 +1,4 @@
-require 'runit/testcase'
-require 'runit/cui/mytestrunner'
-require 'runit/topublic'
+require 'test/unit'
 
 require 'rd/inline-element'
 require 'rd/document-struct'
@@ -10,10 +8,9 @@ include RD
 
 DummyStruct.define_relationship(NonterminalInline, DummyElement)
 
-class TestNonterminalInline < RUNIT::TestCase
-  include RUNIT::ToPublic
+class TestNonterminalInline < Test::Unit::TestCase
   def test_children
-    el = to_public(NonterminalInline).new
+    el = NonterminalInline.new
     assert_equal([], el.children)
     el.children.push 1
     assert_equal([1], el.children)
@@ -33,7 +30,4 @@ class TestNonterminalInline < RUNIT::TestCase
     assert_equal("", zero.to_label)
   end
 end
-  
-if $0 == __FILE__
-  RUNIT::CUI::MyTestRunner.run(TestNonterminalInline.suite)
-end
+
